@@ -403,7 +403,7 @@ main(int argc, char* argv[])
       applet_widget_register_stock_callback(APPLET_WIDGET(window),
 					    "about",
 					    GNOME_STOCK_MENU_ABOUT,
-					    _("About	"),
+					    _("About..."),
 					    about_cb,
 					    NULL);
       applet_widget_register_stock_callback(APPLET_WIDGET(window),
