@@ -1,4 +1,4 @@
-/* $Id: jbc-applet.c,v 1.7 1999/04/14 15:49:38 pablo Exp $
+/* $Id: jbc-applet.c,v 1.7.2.2 1999/08/27 20:39:28 sopwith Exp $
  *
  * Jon's Binary Clock, GNOMEified
  *
@@ -67,8 +67,11 @@ about_jbc ()
 static gint
 do_flicker ()
 {
+  struct tm *tm;
   thetime = time (NULL);
-  localtime_r (&thetime, &atime);
+
+  tm = localtime (&thetime);
+  atime = *tm;
 
   d[0] = atime.tm_hour / 10;
   d[1] = atime.tm_hour % 10;
