@@ -24,19 +24,21 @@
 #include <gnome.h>
 #include <zvt/zvtterm.h>
 
+#include <X11/Xatom.h>
+
 #include "gnome-terminal.h"
 
 /* The program environment */
 extern char **environ;		
 
+/* Initial geometry */
+static char *initial_global_geometry = NULL;
+
 char **env;
 
 #define DEFAULT_FONT "-misc-fixed-medium-r-normal--20-200-75-75-c-100-iso8859-1"
 #define EXTRA 2
 
-/* Initial geometry */
-char *geometry = 0;
-
 /* is there pixmap compiled into zvt */
 static gboolean zvt_pixmap_support = FALSE;
 
@@ -755,11 +757,18 @@ window_destroy (GtkWidget *w, gpointer data)
 {
 	ZvtTerm *term = ZVT_TERM (data);
 	preferences_t *prefs;
+	char *tmp;
 
 	prefs = gtk_object_get_data (GTK_OBJECT (term), "prefs");
 	gtk_signal_disconnect_by_data (GTK_OBJECT (prefs->pixmap_entry), prefs);
 	g_free (prefs);
 	gtk_object_set_data (GTK_OBJECT (term), "prefs", NULL);
+
+	tmp = gtk_object_get_data (GTK_OBJECT (term), "matchstr");
+	if (tmp) {
+		g_free(tmp);
+		gtk_object_set_data(GTK_OBJECT (term), "matchstr", NULL);
+	}
 }
 
 /* 
@@ -1369,7 +1378,7 @@ preferences_cmd (GtkWidget *widget, ZvtTerm *term)
 			    GTK_SIGNAL_FUNC (prop_changed), prefs);
 	gtk_table_attach (GTK_TABLE (table), prefs->scrollback_spin, 2, 3, SCROLLBACK_ROW, 
 			  SCROLLBACK_ROW+1, GTK_FILL, 0, GNOME_PAD, GNOME_PAD);
-	gnome_dialog_editable_enters (GTK_DIALOG (prefs->prop_win),
+	gnome_dialog_editable_enters (GNOME_DIALOG (prefs->prop_win),
 				      GTK_EDITABLE (prefs->scrollback_spin));
 
 	/* Scroll on keystroke checkbox */
@@ -1631,12 +1640,37 @@ static void
 title_changed(ZvtTerm *term, VTTITLE_TYPE type, char *newtitle)
 {
 	GnomeApp *window = GNOME_APP (gtk_widget_get_toplevel (GTK_WIDGET (term)));
+	XTextProperty text_prop;
+	Atom aprop;
+	char *pchEndPropName;
 
 	switch(type){
 	case VTTITLE_WINDOW:
 	case VTTITLE_WINDOWICON:
 		gtk_window_set_title((GtkWindow *)window, newtitle);
 		break;
+	/* this is a enumeration, so we can't #ifdef check it */
+	/* case VTTITLE_XPROPERTY: */
+	case 3:
+		pchEndPropName = strchr(newtitle,'=');
+		if (pchEndPropName)
+			*pchEndPropName = '\0';
+		aprop = XInternAtom(GDK_DISPLAY(), newtitle, False);
+		if (pchEndPropName == NULL) {
+			/* no "=value" given, so delete the property */
+			XDeleteProperty(GDK_DISPLAY(),
+					GDK_WINDOW_XWINDOW(GTK_WIDGET(window)->window),
+					aprop);
+		} else {
+			text_prop.value = pchEndPropName+1;
+			text_prop.encoding = XA_STRING;
+			text_prop.format = 8;
+			text_prop.nitems = strlen(text_prop.value);
+			XSetTextProperty(GDK_DISPLAY(),
+					 GDK_WINDOW_XWINDOW(GTK_WIDGET(window)->window),
+					 &text_prop,aprop);
+		}
+		break;
 	default:
 		break;
 	}
@@ -1778,11 +1812,16 @@ button_press (GtkWidget *widget, GdkEventButton *event, ZvtTerm *term)
 #ifdef ZVT_TERM_MATCH_SUPPORT
 	/* construct the popup menu properly */
 	if (match) {
+		char *tmp;
+
 		memcpy(&gnome_terminal_popup_menu[POPUP_MENU_DYNAMIC_INDEX],
 		       &gnome_terminal_popup_menu_url[0],
 		       sizeof(gnome_terminal_popup_menu_url));
-		
-		gtk_object_set_data (GTK_OBJECT (term), "matchstr", match);
+
+		tmp = gtk_object_get_data(GTK_OBJECT (term), "matchstr");
+		if (tmp)
+			g_free(tmp);
+		gtk_object_set_data (GTK_OBJECT (term), "matchstr", g_strdup(match));
 	} else {
 		/* make sure the optional menu isn't there */
 		memcpy(&gnome_terminal_popup_menu[POPUP_MENU_DYNAMIC_INDEX],
@@ -1984,12 +2023,21 @@ new_terminal_cmd (char **cmd, struct terminal_config *cfg_in, gchar *geometry)
 	 * Handle geometry specification; height and width are in
 	 * terminal rows and columns
 	 */
+	term = (ZvtTerm *)zvt_term_new();
+	if ((zvt_term_get_capabilities (term) & ZVT_TERM_PIXMAP_SUPPORT) != 0){
+		zvt_pixmap_support = TRUE;
+	}
+	gtk_object_set_data(GTK_OBJECT(app), "term", term);
+	gtk_widget_grab_focus(GTK_WIDGET(term));
+
 	width=80;
 	height=24;
-	if (geometry){
+
+	if (geometry) {
 		int xpos, ypos;
-		
+
 		gnome_parse_geometry (geometry, &xpos, &ypos, &width, &height);
+
 		if (xpos != -1 && ypos != -1)
 			gtk_widget_set_uposition (GTK_WIDGET (app), xpos, ypos);
 		if (width == -1 || height == -1) {
@@ -1999,14 +2047,9 @@ new_terminal_cmd (char **cmd, struct terminal_config *cfg_in, gchar *geometry)
 		/* Only the first window gets --geometry treatment for now */
 		geometry = NULL;
 	}
-
-	term = (ZvtTerm *)zvt_term_new_with_size(width, height);
-
-	if ((zvt_term_get_capabilities (term) & ZVT_TERM_PIXMAP_SUPPORT) != 0){
-		zvt_pixmap_support = TRUE;
-	}
-	gtk_object_set_data(GTK_OBJECT(app), "term", term);
+	zvt_term_set_size(term, width, height);
 	gtk_widget_show (GTK_WIDGET (term));
+
 	gtk_signal_connect_object(GTK_OBJECT(app),"configure_event",
 				  GTK_SIGNAL_FUNC(term_change_pos),
 				  GTK_OBJECT(term));
@@ -2178,10 +2221,18 @@ load_session ()
 		g_free (class_path);
 
 		cfg = load_config (class);
-		
+
 		/* do this now, since it is only done in a session */
 		cfg->invoke_as_login_shell = gnome_config_get_bool("invoke_as_login_shell");
-		cfg->termname = gnome_config_get_string("termname");
+		{
+			char *ctmp;
+			ctmp = gnome_config_get_string("termname=xterm");
+			if(ctmp && *ctmp)
+				cfg->termname = g_strconcat("TERM=", ctmp, NULL);
+			else
+				cfg->termname = g_strdup("TERM=xterm");
+			g_free(ctmp);
+		}
 		cfg->window_title = gnome_config_get_string("window_title");
 		if (gnome_config_get_bool ("do_utmp=true"))
 			cfg->update_records |= ZVT_TERM_DO_UTMP_LOG;
@@ -2221,6 +2272,7 @@ save_session (GnomeClient *client, gint phase, GnomeSaveStyle save_style,
 		ZvtTerm *term;
 		GtkWidget *top;
 		char *prefix;
+		char *ctmp;
 	  
 		top = gtk_widget_get_toplevel (GTK_WIDGET (list->data));
 		prefix = g_strdup_printf ("%s%d/", file, i);
@@ -2269,7 +2321,16 @@ save_session (GnomeClient *client, gint phase, GnomeSaveStyle save_style,
 		
 		/* do this now, since it is only done in a session */
 		gnome_config_set_bool("invoke_as_login_shell", cfg->invoke_as_login_shell);
-		gnome_config_set_string("termname", cfg->termname?cfg->termname:"xterm");
+
+		ctmp = NULL;
+		if(cfg->termname) {
+			ctmp = strchr(cfg->termname, '=');
+			if(ctmp) ctmp++;
+		}
+		if(!ctmp)
+			ctmp = "xterm";
+		gnome_config_set_string("termname", ctmp);
+
 		gnome_config_set_string("window_title", cfg->window_title?cfg->window_title:"Terminal");
 		gnome_config_set_bool("do_utmp", (cfg->update_records & ZVT_TERM_DO_UTMP_LOG) != 0);
 		gnome_config_set_bool("do_wtmp", (cfg->update_records & ZVT_TERM_DO_WTMP_LOG) != 0);
@@ -2281,6 +2342,8 @@ save_session (GnomeClient *client, gint phase, GnomeSaveStyle save_style,
 	}
 	gnome_config_push_prefix (file);
 	gnome_config_set_int ("dummy/num_terms", i);
+	gnome_config_pop_prefix ();
+
 #if 0
 	/* What was the cfg variable ? */
 	args[0] = gnome_master_client()->restart_command[0];
@@ -2403,7 +2466,7 @@ parse_an_arg (poptContext state,
 		cmdline_login = TRUE;
 	        break;
 	case GEOMETRY_KEY:
-		geometry = (char *)arg;
+		initial_global_geometry = (char *)arg;
 		break;
 	case COMMAND_KEY:
 		  {
@@ -2578,7 +2641,7 @@ main_terminal_program (int argc, char *argv [], char **environ)
 	terminal_config_free (cmdline_config);
 	
 	if (!load_session ())
-		new_terminal_cmd (initial_command, default_config, geometry);
+		new_terminal_cmd (initial_command, default_config, initial_global_geometry);
 
 	terminal_config_free (default_config);
 
