@@ -96,11 +96,11 @@ drag_data_get_cb (GtkWidget *widget, GdkDragContext     *context,
 	g_return_if_fail(launcher!=NULL);
 	g_return_if_fail(launcher->dentry!=NULL);
 	g_return_if_fail(launcher->dentry->location!=NULL);
-       
+
 	uri_list = g_strconcat ("file:", launcher->dentry->location, "\r\n", NULL);
 
 	gtk_selection_data_set (selection_data,
-				selection_data->target, 8, uri_list,
+				selection_data->target, 8, (guchar *)uri_list,
 				strlen(uri_list));
 	g_free(uri_list);
 }
@@ -282,6 +282,24 @@ create_properties_dialog(Launcher *launcher)
 
 	gnome_dentry_edit_set_dentry(GNOME_DENTRY_EDIT(launcher->dedit),
 				     launcher->dentry);
+
+	/* This sucks, but there is no other way to do this with the current
+	   GnomeDEntry API.  */
+
+#define SETUP_EDITABLE(entry_name)					\
+	gnome_dialog_editable_enters					\
+		(GNOME_DIALOG (dialog),					\
+		 GTK_EDITABLE (gnome_dentry_get_##entry_name##_entry  	\
+			       (GNOME_DENTRY_EDIT (launcher->dedit))));
+
+	SETUP_EDITABLE (name);
+	SETUP_EDITABLE (comment);
+	SETUP_EDITABLE (exec);
+	SETUP_EDITABLE (tryexec);
+	SETUP_EDITABLE (doc);
+	SETUP_EDITABLE (icon);
+
+#undef SETUP_EDITABLE
 	
 	gtk_signal_connect_object(GTK_OBJECT(launcher->dedit), "changed",
 				  GTK_SIGNAL_FUNC(gnome_property_box_changed),
@@ -354,6 +372,7 @@ really_add_launcher(GtkWidget *d,int button, gpointer data)
 			dentry->name=g_strdup("???");
 		}
 		_load_launcher_applet(NULL, dentry, panel, pos);
+		panel_config_sync();
 	}
 	gtk_widget_destroy(d);
 }
@@ -414,6 +433,7 @@ load_launcher_applet_from_info(char *name, char *comment,
 		dentry->icon = g_strdup(icon);
 
 	_load_launcher_applet(NULL,dentry,panel, pos);
+	panel_config_sync();
 }
 
 void
